@@ -53,12 +53,13 @@ class AddSmsSignRequest(AbstractModel):
 Note: you cannot apply for an approved or pending signature again.
         :type SignName: str
         :param SignType: Signature type. Each of these types is followed by their `DocumentType` (identity certificate type) option:
-0: company. Valid values of `DocumentType` include 0, 1, 2, and 3.
+0: company. Valid values of `DocumentType` include 0 and 1.
 1: app. Valid values of `DocumentType` include 0, 1, 2, 3, and 4.
 2: website. Valid values of `DocumentType` include 0, 1, 2, 3, and 5.
-3: WeChat Official Account or WeChat Mini Program. Valid values of `DocumentType` include 0, 1, 2, 3, and 6.
+3: WeChat Official Account. Valid values of `DocumentType` include 0, 1, 2, 3, and 8.
 4: trademark. Valid values of `DocumentType` include 7.
 5: government/public institution/other. Valid values of `DocumentType` include 2 and 3.
+6: WeChat Mini Program. Valid values of `DocumentType` include 0, 1, 2, 3, and 6.
 Note: the identity certificate type must be selected according to the correspondence; otherwise, the review will fail.
         :type SignType: int
         :param DocumentType: Identity certificate type:
@@ -70,7 +71,7 @@ Note: the identity certificate type must be selected according to the correspond
 5: screenshot of website ICP filing backend (for personal website).
 6: screenshot of WeChat Mini Program settings page (for personal WeChat Mini Program).
 7: trademark registration certificate.
-Note: the corresponding `DocumentType` must be selected according to `SignType`.
+8: screenshot of WeChat Official Account settings page (for personal WeChat Official Account).
         :type DocumentType: int
         :param International: Whether it is Global SMS:
 0: Mainland China SMS.
@@ -661,21 +662,31 @@ class DescribeSmsTemplateListRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param TemplateIdSet: Template ID array.
-<dx-alert infotype="notice" title="Note">The max array length is 100 by default.</dx-alert>
-        :type TemplateIdSet: list of int non-negative
         :param International: Whether it is Global SMS:
 0: Mainland China SMS.
 1: Global SMS.
         :type International: int
+        :param TemplateIdSet: Array of template IDs. If the array is empty, the template list information will be queried by default (only allowed for root accounts). You need to use the `Limit` and `Offset` fields to set the query range.
+<dx-alert infotype="notice" title="Note">The default array length can be up to 100</dx-alert>
+        :type TemplateIdSet: list of int non-negative
+        :param Limit: Upper limit. Maximum value: 100.
+Note: it is 0 by default and is enabled when `TemplateIdSet` is empty.
+        :type Limit: int
+        :param Offset: Offset.
+Note: it is 0 by default and is enabled when `TemplateIdSet` is empty.
+        :type Offset: int
         """
-        self.TemplateIdSet = None
         self.International = None
+        self.TemplateIdSet = None
+        self.Limit = None
+        self.Offset = None
 
 
     def _deserialize(self, params):
-        self.TemplateIdSet = params.get("TemplateIdSet")
         self.International = params.get("International")
+        self.TemplateIdSet = params.get("TemplateIdSet")
+        self.Limit = params.get("Limit")
+        self.Offset = params.get("Offset")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -795,12 +806,13 @@ class ModifySmsSignRequest(AbstractModel):
         :param SignName: Signature name.
         :type SignName: str
         :param SignType: Signature type. Each of these types is followed by their `DocumentType` (identity certificate type) option:
-0: company. Valid values of `DocumentType` include 0, 1, 2, and 3.
+0: company. Valid values of `DocumentType` include 0 and 1.
 1: app. Valid values of `DocumentType` include 0, 1, 2, 3, and 4.
 2: website. Valid values of `DocumentType` include 0, 1, 2, 3, and 5.
-3: WeChat Official Account or WeChat Mini Program. Valid values of `DocumentType` include 0, 1, 2, 3, and 6.
+3: WeChat Official Account. Valid values of `DocumentType` include 0, 1, 2, 3, and 8.
 4: trademark. Valid values of `DocumentType` include 7.
 5: government/public institution/other. Valid values of `DocumentType` include 2 and 3.
+6: WeChat Mini Program. Valid values of `DocumentType` include 0, 1, 2, 3, and 6.
 Note: the identity certificate type must be selected according to the correspondence; otherwise, the review will fail.
         :type SignType: int
         :param DocumentType: Identity certificate type:
@@ -812,7 +824,7 @@ Note: the identity certificate type must be selected according to the correspond
 5: screenshot of website ICP filing backend (for personal website).
 6: screenshot of WeChat Mini Program settings page (for personal WeChat Mini Program).
 7: trademark registration certificate.
-Note: the corresponding `DocumentType` must be selected according to `SignType`.
+8: screenshot of WeChat Official Account settings page (for personal WeChat Official Account).
         :type DocumentType: int
         :param International: A parameter used to specify whether it is Global SMS:
 `0`: Chinese mainland SMS.
@@ -1387,20 +1399,20 @@ Note: 11-digit Chinese mainland numbers prefixed by 0086 or 86 or those without
         :type PhoneNumberSet: list of str
         :param SmsSdkAppId: The SMS `SdkAppId` generated after an application is added in the [SMS console](https://console.cloud.tencent.com/smsv2/app-manage), such as 1400006666.
         :type SmsSdkAppId: str
-        :param TemplateId: Template ID. You must enter the ID of an approved template, which can be viewed in the [SMS console](https://console.cloud.tencent.com/smsv2). If you need to send SMS messages to global mobile numbers, you can only use a Global SMS template.
+        :param TemplateId: Template ID. You must enter the ID of an approved template, which can be viewed on the [Mainland China SMS](https://console.cloud.tencent.com/smsv2/csms-template) or [Global SMS](https://console.cloud.tencent.com/smsv2/isms-template) body template management page. If you need to send SMS messages to global mobile numbers, you can only use a Global SMS template.
         :type TemplateId: str
-        :param SignName: SMS signature information which is encoded in UTF-8. You must enter an approved signature (such as Tencent Cloud). The signing information can be viewed in the [SMS console](https://console.cloud.tencent.com/smsv2).
-<dx-alert infotype="notice" title="Note">This parameter is required for Chinese mainland SMS.</dx-alert>
+        :param SignName: Content of the SMS signature, which should be encoded in UTF-8. You must enter an approved signature, such as Tencent Cloud. The signature information can be viewed on the [Mainland China SMS](https://console.cloud.tencent.com/smsv2/csms-sign) or [Global SMS](https://console.cloud.tencent.com/smsv2/isms-sign) signature management page.
+<dx-alert infotype="notice" title="Note">This parameter is required for Mainland China SMS.</dx-alert>
         :type SignName: str
         :param TemplateParamSet: Template parameter. If there is no template parameter, leave this field empty.
 <dx-alert infotype="notice" title="Note">The number of template parameters should be consistent with that of the template variables of `TemplateId`.</dx-alert>
         :type TemplateParamSet: list of str
-        :param ExtendCode: SMS code number extension, which is not activated by default. If you need to activate it, please contact [SMS Helper](https://intl.cloud.tencent.com/document/product/382/3773?from_cn_redirect=1#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81).
+        :param ExtendCode: SMS code number extension, which is not activated by default. If you need to activate it, you can contact [SMS Helper](https://intl.cloud.tencent.com/document/product/382/3773?from_cn_redirect=1#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81).
         :type ExtendCode: str
         :param SessionContext: User session content, which can carry context information such as user-side ID and will be returned as-is by the server.
         :type SessionContext: str
         :param SenderId: This parameter is not required for Mainland China SMS. For Global SMS, if you have applied for a separate `SenderId`, this parameter is required. By default, the public `SenderId` is used, in which case you don't need to enter this parameter.
-Note: if your monthly usage reaches the specified threshold, you can apply for an independent `SenderId`. For more information, please contact [SMS Helper](https://intl.cloud.tencent.com/document/product/382/3773?from_cn_redirect=1#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81).
+Note: if your monthly usage reaches the specified threshold, you can apply for an independent `SenderId`. For more information, contact [SMS Helper](https://intl.cloud.tencent.com/document/product/382/3773?from_cn_redirect=1#.E6.8A.80.E6.9C.AF.E4.BA.A4.E6.B5.81).
         :type SenderId: str
         """
         self.PhoneNumberSet = None
@@ -1468,11 +1480,11 @@ class SendStatus(AbstractModel):
         :type SerialNo: str
         :param PhoneNumber: Mobile number in the E.164 standard (+[country/region code][mobile number]), such as +8613711112222, which has a + sign followed by 86 (country/region code) and then by 13711112222 (mobile number).
         :type PhoneNumber: str
-        :param Fee: Number of billable SMS messages. For billing rules, please see [Billing Policy](https://intl.cloud.tencent.com/document/product/382/36135?from_cn_redirect=1).
+        :param Fee: Number of billable SMS messages. For billing rules, see Billing Policy.
         :type Fee: int
         :param SessionContext: User session content.
         :type SessionContext: str
-        :param Code: SMS request error code. For details, see [Error Codes](https://intl.cloud.tencent.com/document/api/382/55981?from_cn_redirect=1#6.-.E9.94.99.E8.AF.AF.E7.A0.81). `Ok` will be returned if the request is successful.
+        :param Code: SMS request error code. For specific meanings, see [Error Codes](https://intl.cloud.tencent.com/zh/document/product/382/40536#6.-error-code). `Ok` will be returned for successful delivery.
         :type Code: str
         :param Message: SMS request error message.
         :type Message: str
